///////////////////////////////////////////////////////////////////////////////
//
//    (C) Copyright 2009-2010 OSR Open Systems Resources, Inc.
//    All Rights Reserved
//
//    This work is distributed under the OSR Non-Commercial Software License
//    which is provided at
//    "http://www.osronline.com/page.cfm?name=NonCommLicense" in
//    the hope that it will be enlightening, but WITHOUT ANY
//    WARRANTY; without even the implied warranty of
//    MECHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
//            OSR Open Systems Resources, Inc.
//            105 Route 101A Suite 19
//            Amherst, NH 03031  (603) 595-6500 FAX: (603) 595-6503
// 
//    MODULE:
//
//        apexts.cpp -- Sample debugger extension
//
//    ABSTRACT:
//
//       Main entry points for the debugger extension
//
//    AUTHOR(S):
//
//        OSR Open Systems Resources, Inc.
// 
//    REVISION:   
//
//
///////////////////////////////////////////////////////////////////////////////
#include "apexts.h"

///////////////////////////////////////////////////////////////////////////////
//
//  DebugExtensionInitialize
//
//    Called to do one time initialization of our DLL.
// 
//    Required entry point.
//
///////////////////////////////////////////////////////////////////////////////
extern "C"
HRESULT
CALLBACK
DebugExtensionInitialize(
    PULONG Version, 
    PULONG Flags
    ) {

    // 
    // We're version 1.0 of our extension DLL
    // 
    *Version = DEBUG_EXTENSION_VERSION(1, 0);

    // 
    // Flags must be zero
    // 
    *Flags = 0;

    // 
    // Done!
    // 
    return S_OK;
}

///////////////////////////////////////////////////////////////////////////////
//
//  DebugExtensionNotify
//
//    Called to notify us of session state changes.
// 
//    Not a required entry point.
//
///////////////////////////////////////////////////////////////////////////////
extern "C"
VOID
CALLBACK
DebugExtensionNotify(
    ULONG Notify, 
    ULONG64 Argument
    ) {

    UNREFERENCED_PARAMETER(Argument);

    switch (Notify) {
    case DEBUG_NOTIFY_SESSION_ACTIVE:
        //
        // A debuggee has been discovered for the session.
        // It is not necessarily halted.
        // 
        break;
    case DEBUG_NOTIFY_SESSION_INACTIVE:
        //
        // The session no longer has a debuggee.
        // 
        break;
    case DEBUG_NOTIFY_SESSION_ACCESSIBLE:
        //
        // The debuggee is halted and accessible.
        // 
        break;
    case DEBUG_NOTIFY_SESSION_INACCESSIBLE:
        //
        // The debuggee is running or inaccessible.
        // 
        break;
    default:
        // 
        // Shouldn't be here.
        // 
        break;
    }
    return;
}

///////////////////////////////////////////////////////////////////////////////
//
//  DebugExtensionUninitialize
//
//    Called to undo any work done in DebugExtensionInitialize. 
// 
//    Not a required entry point.
//
///////////////////////////////////////////////////////////////////////////////
extern "C"
VOID
CALLBACK
DebugExtensionUninitialize(
    VOID
    ) {
    // 
    // Nothing to do in this extension.
    // 
    return;
}




